@@ -361,7 +361,7 @@ metas:
         work_path,
         task_id,
     ):
-
+        image = None
         verbose = form_data.get('verbose', False)
         session_id = req_header.get('jinameta-session-id')
 
@@ -425,6 +425,8 @@ metas:
         else:
             raise Exception(f'Error: can\'t get task_id session_id: {session_id}')
 
+        return image
+
     def _sync_push(
         self, console, st, req_header, content, form_data, work_path, uuid8, secret
     ):
@@ -510,6 +512,9 @@ metas:
         else:
             raise Exception(f'Unknown Error, session_id: {session_id}')
 
+        return image
+
+    @hubble.login_required
     def push(self) -> None:
         """Push the Executor package to Jina Hub."""
 
@@ -517,6 +522,8 @@ metas:
 
         exec_tags = None
         exec_immutable_tags = None
+        image = None
+
         if self.args.tag:
             exec_tags = ','.join(self.args.tag)
         if self.args.protected_tag:
@@ -639,7 +646,7 @@ metas:
 
                 logged_in = True if hubble.is_logged_in() else False
                 if logged_in:  # if user logged in use async upload api
-                    self._async_push(
+                    image = self._async_push(
                         console,
                         st,
                         req_header,
@@ -651,7 +658,7 @@ metas:
 
                 else:
                     # if user not logged in use async upload api
-                    self._sync_push(
+                    image = self._sync_push(
                         console,
                         st,
                         req_header,
@@ -672,6 +679,8 @@ metas:
                 )
                 raise e
 
+        return image
+
     def _prettyprint_result(
         self, console, image, *, warnings: Optional[List[str]] = None
     ):
@@ -840,24 +849,25 @@ metas:
         )
 
         param_str.add_column(
-            'If you don\'t want to wait for the Executor\'s build status, you can use \'Ctrl + C\'. '
-            'After that you can get the status of the Executor any time using the command.'
+            'If you don\'t want to wait for the build result, you can interrupt it with \'Ctrl + C\'. '
+            'You can resume the build progress at any time.'
         )
         param_str.add_row(
-            f'Use `jina hub status {work_path}` to get the last build status of the Executor',
+            f'Run `jina hub status {work_path}` to check the latest build status of the '
+            'Executor in the current working directory',
         )
 
         if task_id:
             param_str.add_row('')
             param_str.add_row(
-                f'You can also use `jina hub status --id {task_id}` '
-                'to get the specified build status of the Executor.',
+                f'You can also run `jina hub status --id {task_id} --replay --verbose` '
+                'to get the full log of this particular build.',
             )
 
         console.print(
             Panel(
                 param_str,
-                title='Status',
+                title='Building',
                 expand=False,
                 width=100,
             )
